@@ -11,7 +11,7 @@ from montecarlodata.integrations.onboarding.fields import GQL_TO_FRIENDLY_CONNEC
 
 
 class OnboardingStatusService:
-    _INTEGRATION_FRIENDLY_HEADERS = ['Integration', 'ID', 'Created on (UTC)']
+    _INTEGRATION_FRIENDLY_HEADERS = ['Integration', 'ID', 'Connection', 'Created on (UTC)']
 
     def __init__(self, config: Config, user_service: Optional[UserService] = None):
         self._abort_on_error = True
@@ -32,15 +32,24 @@ class OnboardingStatusService:
             table += self._build_table_record(connections=integration.get('connections'))
         click.echo(tabulate(table, headers=headers, tablefmt=table_format))
 
-    @staticmethod
-    def _build_table_record(connections: List[Dict]) -> List[List[str]]:
+    def _build_table_record(self, connections: List[Dict]) -> List[List[str]]:
         table = []
         for connection in connections or []:
             table.append(
                 [
                     GQL_TO_FRIENDLY_CONNECTION_MAP.get(normalize_gql(connection['type']), connection['type']),
                     connection['uuid'],
+                    self._build_connection_info(connection),
                     connection['createdOn']
                 ]
             )  # order by the friendly headers, defaulting to gql response if not found
         return table
+
+    @staticmethod
+    def _build_connection_info(connection: Dict) -> Optional[str]:
+        identifier = connection.get('connectionIdentifier')
+        if identifier:
+            key = identifier.get('key')
+            value = identifier.get('value')
+            return f'{key}: {value}'
+        return None
