@@ -10,6 +10,7 @@ EXPECTED_ATHENA_GQL_RESPONSE_FIELD = 'testAthenaCredentials'
 EXPECTED_SPARK_GQL_RESPONSE_FIELD = 'testSparkCredentials'
 EXPECTED_SNOWFLAKE_GQL_RESPONSE_FIELD = 'testSnowflakeCredentials'
 EXPECTED_BQ_GQL_RESPONSE_FIELD = 'testBqCredentials'
+EXPECTED_SELF_HOSTED_GQL_RESPONSE_FIELD = 'testSelfHostedCredentials'
 EXPECTED_TOGGLE_EVENTS_GQL_RESPONSE_FIELD = 'toggleEventConfig'
 EXPECTED_UPDATE_CREDENTIALS_RESPONSE_FIELD = 'updateCredentials'
 EXPECTED_REMOVE_CONNECTION_RESPONSE_FIELD = 'removeConnection'
@@ -18,9 +19,12 @@ EXPECTED_TEST_TABLEAU_RESPONSE_FIELD = 'testTableauCredentials'
 EXPECTED_ADD_TABLEAU_RESPONSE_FIELD = 'addTableauAccount'
 EXPECTED_LOOKER_METADATA_RESPONSE_FIELD = 'testLookerCredentials'
 EXPECTED_LOOKER_GIT_SSH_RESPONSE_FILED = 'testLookerGitSshCredentials'
+EXPECTED_LOOKER_GIT_CLONE_RESPONSE_FIELD = 'testLookerGitCloneCredentials'
+EXPECTED_DBT_CLOUD_RESPONSE_FIELD = 'testDbtCloudCredentials'
 EXPECTED_ADD_BI_RESPONSE_FIELD = 'addBiConnection'
 
 # Available connections types
+AIRFLOW_LOGS_CONNECTION_TYPE = 's3-airflow-log-events'
 HIVE_MYSQL_CONNECTION_TYPE = 'hive-mysql'
 HIVE_S3_CONNECTION_TYPE = 'hive-s3'
 HIVE_SQL_CONNECTION_TYPE = 'hive'
@@ -34,6 +38,8 @@ SNOWFLAKE_CONNECTION_TYPE = 'snowflake'
 BQ_CONNECTION_TYPE = 'bigquery'
 LOOKER_MD_CONNECTION_TYPE = 'looker'
 LOOKER_GIT_SSH_CONNECTION_TYPE = 'looker-git-ssh'
+LOOKER_GIT_CLONE_CONNECTION_TYPE = 'looker-git-clone'
+DBT_CLOUD_CONNECTION_TYPE = 'dbt-cloud'
 
 # Available warehouse types
 DATA_LAKE_WAREHOUSE_TYPE = 'data-lake'
@@ -41,7 +47,18 @@ REDSHIFT_WAREHOUSE_TYPE = REDSHIFT_CONNECTION_TYPE
 SNOWFLAKE_WAREHOUSE_TYPE = SNOWFLAKE_CONNECTION_TYPE
 BQ_WAREHOUSE_TYPE = BQ_CONNECTION_TYPE
 
+CONNECTION_TO_WAREHOUSE_TYPE_MAP = {
+    BQ_CONNECTION_TYPE: BQ_WAREHOUSE_TYPE,
+    REDSHIFT_CONNECTION_TYPE: REDSHIFT_WAREHOUSE_TYPE,
+    SNOWFLAKE_CONNECTION_TYPE: SNOWFLAKE_WAREHOUSE_TYPE,
+}
+
+# Available credential self-hosting mechanisms
+SECRETS_MANAGER_CREDENTIAL_MECHANISM = 'secretsmanager'
+SELF_HOSTING_MECHANISMS = [SECRETS_MANAGER_CREDENTIAL_MECHANISM]
+
 # S3 event types
+AIRFLOW_LOGS_EVENT_TYPE = 's3_airflow_log_events'
 S3_METADATA_EVENT_TYPE = 's3_metadata_events'
 S3_QL_EVENT_TYPE = 's3_ql_events'
 
@@ -61,6 +78,7 @@ AWS_RDS_CA_CERT = 'https://s3.amazonaws.com/rds-downloads/rds-combined-ca-bundle
 
 # Connections to friendly name (i.e. human presentable) map
 GQL_TO_FRIENDLY_CONNECTION_MAP = {
+    AIRFLOW_LOGS_CONNECTION_TYPE: 'Airflow Logs',
     HIVE_MYSQL_CONNECTION_TYPE: 'Hive (metastore)',
     HIVE_S3_CONNECTION_TYPE: 'Hive (EMR logs)',
     HIVE_SQL_CONNECTION_TYPE: 'Hive (SQL)',
@@ -73,7 +91,9 @@ GQL_TO_FRIENDLY_CONNECTION_MAP = {
     SNOWFLAKE_CONNECTION_TYPE: SNOWFLAKE_CONNECTION_TYPE.capitalize(),
     BQ_CONNECTION_TYPE: 'BigQuery',
     LOOKER_MD_CONNECTION_TYPE: 'Looker (metadata)',
-    LOOKER_GIT_SSH_CONNECTION_TYPE: 'Looker ML (git)'
+    LOOKER_GIT_SSH_CONNECTION_TYPE: 'Looker ML (git)',
+    LOOKER_GIT_CLONE_CONNECTION_TYPE: 'Looker ML (git)',
+    DBT_CLOUD_CONNECTION_TYPE: 'dbt Cloud',
 }
 
 # Verbiage
