@@ -17,6 +17,10 @@ query getUser {
           type
           createdOn
           jobTypes
+          connectionIdentifier {
+            key
+            value
+          }
         }
         dataCollector {
           uuid
